@@ -8,8 +8,8 @@
 // Software.
 
 use super::ipc::IpcError;
-use sn_client::Error as ClientError;
-use sn_url::Error as SafeUrlError;
+use safe_network::client::Error as ClientError;
+use safe_network::url::Error as SafeUrlError;
 use thiserror::Error;
 
 pub type Result<T> = std::result::Result<T, Error>;
